@@ -2,7 +2,7 @@ package ExtUtils::ModuleMaker::PBP;
 use strict;
 use warnings;
 our ( $VERSION );
-$VERSION = '0.03';
+$VERSION = '0.04';
 use base qw( ExtUtils::ModuleMaker );
 
 =head1 NAME
@@ -35,8 +35,8 @@ ExtUtils::ModuleMaker::PBP - Create a Perl extension in the style of Damian Conw
 
 =head1 VERSION
 
-This document references version 0.03 of ExtUtils::ModuleMaker::PBP, released
-to CPAN on September 11, 2005.
+This document references version 0.04 of ExtUtils::ModuleMaker::PBP, released
+to CPAN on September 15, 2005.
 
 =head1 DESCRIPTION
 
@@ -310,9 +310,9 @@ END_OF_README
             $README_bottom;
 }
 
-=head3 C<compose_pm_file()>
+=head3 C<text_pm_file()>
 
-  Usage     : $self->compose_pm_file($module) within generate_pm_file()
+  Usage     : $self->text_pm_file($module) within generate_pm_file()
   Purpose   : Composes a string holding all elements for a pm file
   Returns   : String holding text for a *.pm file
   Argument  : $module: pointer to the module being built
@@ -323,7 +323,7 @@ END_OF_README
 
 =cut
 
-sub compose_pm_file {
+sub text_pm_file {
     my $self = shift;
     my $module = shift;
       
